# Required Packages
require(lme4)
require(bbmle)
require(glmmTMB)

# Reading in Aggregated Data File
X<-read.csv("Shea_Supp_Data_File.csv")



# Subset dataframe to include only microparasites that were detected at one or more sites (Exclude all species that were negative across all sites and all seasons)
# Pathogen Spp 1-22 were detected at one or more sites
Sub_Spp<-seq(from=1, to=22, by=1)
Sub_Spp<-as.factor(Sub_Spp)

X_Sub<-X[X$Microparasite_Spp %in% Sub_Spp[1:22],]
nrow(X_Sub)

# Generating simplified dataframe which only includes columns required for GLMM models
Year<-X_Sub$Year    # Sampling Year
Year<-as.factor(Year)

Site<-X_Sub$Site    # Factor specifying site identity
Site<-as.factor(Site)

Status<-X_Sub$Active  # Status of salmon farm tenure (active salmon farm=1, no active salmon farm=0)
Status<-as.numeric(Status)

Atl_eDNA<-X_Sub$Atl_eDNA_Centered # relative Atlantic salmon eDNA concentration (inverse of Ct-values centered around the mean value for each season)

Spp<-X_Sub$Microparasite_Spp    # A factor assigning a unique level for each of the 22 microparasite species that were detected at 1 or or more sites
Spp<-as.factor(Spp)

Detection<-X_Sub$Binary_Microparasite_Detection     # Binary presence absence response variable for each pathogen 
Detection<-as.factor(Detection)
# *Each instance where a microparasite Ct-value < 35 at a given site was assigned a 1, 
# Each instance where a species was assayed and not observed was assigned a 0
# Each instances where an agent was not assayed in a given sampling year were assigned NA

Spp_Names<-X_Sub$Microparasite_Spp_Names



x<-data.frame(Year, Site, Status, Atl_eDNA, Spp_Names, Spp, Detection)


###################################################################
# Multi-year GLMM's with sampling year modeled as a fixed effect. 
# We include a random effect of Site on the intercept and a random effect of microparasite species on the intercept and slope of the predictor

# Null Model (Only Random Effects)
m01<-glmmTMB(Detection ~ Year-1 + (1|Spp) + (1|Site) , family='binomial' , data=x); summary(m01)

# Farm Status Model
mA1<-glmmTMB(Detection ~ Year-1 + Status + (Status|Spp) + (1|Site) , family='binomial' , data=x); summary(mA1)

# Atlantic salmon eDNA
mS1<-glmmTMB(Detection ~ Year-1 + Atl_eDNA + (Atl_eDNA|Spp) + (1|Site) , family='binomial' , data=x); summary(mS1)

#Comparing site status model and Atlantic salmon eDNA model to null
bbmle::AICctab(mA1, mS1, m01, logLik=T,base=TRUE, weights=TRUE, nobs=134)


